@@ -1,17 +1,21 @@
+# Copyright 2021-2022 Boris Shminke
+
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+
+#     https://www.apache.org/licenses/LICENSE-2.0
+
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 """
-Copyright 2021 Boris Shminke
+Agent Testing
+==============
 
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
-
-    https://www.apache.org/licenses/LICENSE-2.0
-
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
+This module is an example of testing your own trained agent.
 """
 import random
 import sys
@@ -22,6 +26,7 @@ from operator import itemgetter
 from typing import Any, Dict, List, Optional
 
 import gym
+from gym.wrappers import TimeLimit
 
 from gym_saturation.envs import SaturationEnv
 from gym_saturation.envs.saturation_env import STATE_DIFF_UPDATED
@@ -72,7 +77,11 @@ class Transition:
 
 
 class SizeAgent(BaseAgent):
-    """agent which selects the shortest clause"""
+    """
+    .. _size_agent:
+
+    agent which selects the shortest clause
+    """
 
     def __init__(self):
         self._state: Dict[int, float] = {}
@@ -109,7 +118,11 @@ class SizeAgent(BaseAgent):
 
 
 class AgeAgent(BaseAgent):
-    """agent which selects the oldest clause"""
+    """
+    .. _age_agent:
+
+    agent which selects the oldest clause
+    """
 
     def get_action(
         self,
@@ -128,6 +141,8 @@ class AgeAgent(BaseAgent):
 
 class SizeAgeAgent(BaseAgent):
     """
+    .. _size_age_agent:
+
     agent which takes several times the smallest clause and then several
     times the oldest
     """
@@ -196,23 +211,25 @@ def episode(
     >>> from glob import glob
     >>> problem_list = sorted(glob(os.path.join(
     ...     files("gym_saturation")
-    ...     .joinpath("resources/TPTP-mock/Problems/TST")
+    ...     .joinpath(os.path.join(
+    ...         "resources", "TPTP-mock", "Problems", "TST"
+    ...     ))
     ... , "*-*.p")))
     >>> random.seed(0)
     >>> agents = [SizeAgeAgent(2, 1), SizeAgeAgent(1, 2), RandomAgent()]
     >>> for i in range(3):  # doctest: +ELLIPSIS
     ...     env = gym.make(
     ...         "gym_saturation:saturation-v0",
-    ...         step_limit=5,
     ...         problem_list=[problem_list[i]],
     ...     )
+    ...     env._max_episode_steps = 5
     ...     agent_testing_report(env, agents[i])
     Proof of length 1 found in 4 steps:
-    cnf(..., hypothesis, $false, inference(resolution, [], [this_is_a_test_case_1, this_is_a_test_case_2])).
+    cnf(..., lemma, $false, inference(resolution, [], [this_is_a_test_case_1, this_is_a_test_case_2])).
     Step limit reached
     Proof of length 2 found in 5 steps:
-    cnf(..., ..., ~man(socrates), inference(resolution, [], [q, p_imp_q])).
-    cnf(..., hypothesis, $false, inference(resolution, [], [p, ...])).
+    cnf(..., lemma, ..., inference(resolution, [], [..., ...])).
+    cnf(..., lemma, $false, inference(resolution, [], [..., ...])).
 
     :param env: a `gym_saturation` environment
     :param agent: an initialized agent. Must have `get_action` method
@@ -274,22 +291,51 @@ def agent_testing_report(env: SaturationEnv, agent: BaseAgent) -> None:
     if last_transition.reward == 1.0:
         a_proof = env.tstp_proof
         proof_length = len(a_proof.split("\n"))
+        step_count = getattr(env, "_elapsed_steps")
         print(
-            f"Proof of length {proof_length} found "
-            f"in {env.step_count} steps:"
+            f"Proof of length {proof_length} found " f"in {step_count} steps:"
         )
         print(a_proof)
     else:
         print("Step limit reached")
 
 
-if __name__ == "__main__":
+def main(args: Optional[List[str]] = None) -> None:
+    """
+    the main function for this module
+
+    >>> if sys.version_info.major == 3 and sys.version_info.minor >= 9:
+    ...     from importlib.resources import files
+    ... else:
+    ...     from importlib_resources import files
+    >>> import os
+    >>> problem_filename = os.path.join(
+    ...     files("gym_saturation")
+    ...     .joinpath(os.path.join(
+    ...         "resources", "TPTP-mock", "Problems", "TST", "TST001-1.p"
+    ...     ))
+    ... )
+    >>> main([
+    ...     "--problem_filename", problem_filename,
+    ...     "--step_limit", "3"
+    ... ]) # doctest: +ELLIPSIS
+    Problem file: ...TST001-1.p
+    Proof of length 1 found in 3 steps:
+    cnf(..., lemma, $false, inference(resolution, [], [this_is_a_test_case_1, this_is_a_test_case_2])).
+
+    """
     sys.setrecursionlimit(10000)
-    arguments = parse_args()
-    environment = gym.make(
-        "gym_saturation:saturation-v0",
-        step_limit=arguments.step_limit,
-        problem_list=[arguments.problem_filename],
+    arguments = parse_args(args)
+    environment = TimeLimit(
+        gym.make(
+            "gym_saturation:saturation-v0",
+            problem_list=[arguments.problem_filename],
+        ),
+        arguments.step_limit,
     )
-    print(arguments.problem_filename)
+    print(f"Problem file: {arguments.problem_filename}")
     agent_testing_report(environment, SizeAgeAgent(5, 1))
+
+
+if __name__ == "__main__":
+    main()
