@@ -1,17 +1,19 @@
+# Copyright 2021-2022 Boris Shminke
+
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+
+#     https://www.apache.org/licenses/LICENSE-2.0
+
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 """
-Copyright 2021 Boris Shminke
-
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
-
-    https://www.apache.org/licenses/LICENSE-2.0
-
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
+Paramodulation
+===============
 """
 from typing import List, Tuple
 
@@ -37,6 +39,8 @@ def paramodulation(
     r_position: int,
 ) -> Clause:
     r"""
+    .. _paramodulation:
+
     binary paramodulation rule
 
     .. math:: {\frac{C_1\vee s\approx t,C_2\vee L\left[r\right]}{\sigma\left(L\left[t\right]\vee C_1\vee C_2\right)}}
@@ -198,9 +202,9 @@ def all_paramodulants_from_list(
     >>> res = all_paramodulants_from_list([one], two)
     >>> dedup = map(Clause, deduplicate([clause.literals for clause in res]))
     >>> print("\\n".join(map(str, dedup)))  # doctest: +ELLIPSIS
-    cnf(..., hypothesis, a = c | X = X).
-    cnf(..., hypothesis, c = b | a = b).
-    cnf(..., hypothesis, b = c | a = b).
+    cnf(..., lemma, a = c | X = X).
+    cnf(..., lemma, c = b | a = b).
+    cnf(..., lemma, b = c | a = b).
 
     :param clauses: a list of (processed) clauses
     :param given_clause: a new clause which should be combined with all the
