@@ -1,18 +1,21 @@
+# Copyright 2021-2022 Boris Shminke
+
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+
+#     https://www.apache.org/licenses/LICENSE-2.0
+
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 """
-Copyright 2021 Boris Shminke
-
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
-
-    https://www.apache.org/licenses/LICENSE-2.0
-
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
+JSONEncoder for the grammar
+============================
 """
+
 import json
 from typing import Dict, List, Union
 
@@ -91,7 +94,11 @@ class ClauseJSONEncoder(json.JSONEncoder):
 
 
 def dict_to_clause(json_dict):
-    """get ``Clause`` from a Python dictionary"""
+    """
+    .. _dict_to_clause:
+
+    get ``Clause`` from a Python dictionary
+    """
     if json_dict["class"] == "Clause":
         return grammar.Clause(
             [dict_to_clause(literal) for literal in json_dict["literals"]],
