@@ -1,17 +1,19 @@
+# Copyright 2021-2022 Boris Shminke
+
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+
+#     https://www.apache.org/licenses/LICENSE-2.0
+
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 """
-Copyright 2021 Boris Shminke
-
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
-
-    https://www.apache.org/licenses/LICENSE-2.0
-
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
+TPTP Parser
+===========
 """
 import os
 import sys
@@ -40,24 +42,27 @@ class TPTPParser:
     >>> tptp_parser = TPTPParser()
     >>> tptp_text = (
     ...     files("gym_saturation")
-    ...     .joinpath("resources/TPTP-mock/Problems/TST/TST001-1.p")
+    ...     .joinpath(os.path.join(
+    ...         "resources", "TPTP-mock", "Problems", "TST", "TST001-1.p"
+    ...     ))
     ...     .read_text()
     ... )
     >>> print("\\n".join(map(str, tptp_parser.parse(
     ...     tptp_text,
-    ...     files("gym_saturation").joinpath("resources/TPTP-mock")
+    ...     files("gym_saturation")
+    ...     .joinpath(os.path.join("resources", "TPTP-mock"))
     ... ))))
     cnf(this_is_a_test_case_1, hypothesis, this_is_a_test_case(test_constant), inference(resolution, [], [one, two])).
     cnf(this_is_a_test_case_2, hypothesis, ~this_is_a_test_case(test_constant)).
-    cnf(test_axiom, hypothesis, test_constant = X).
-    cnf(test_axiom_2, hypothesis, ~test_constant = 0).
+    cnf(test_axiom, axiom, test_constant = X).
+    cnf(test_axiom_2, axiom, ~test_constant = 0).
     """
 
     def __init__(self):
         # pylint: disable=unspecified-encoding
         self.parser = Lark(
             files("gym_saturation")
-            .joinpath("resources/TPTP.lark")
+            .joinpath(os.path.join("resources", "TPTP.lark"))
             .read_text(),
             start="tptp_file",
         )
